DeLU (Deep Learning Utilities)
==============================

`Documentation <https://yura52.github.io/delu>`_

.. __INCLUDE_0__

**DeLU is a minimalistic PyTorch toolbox** consisting of two parts:

#. Direct extensions to existing PyTorch modules
   aimed at improving the day-to-day experience with PyTorch
   (``delu.nn`` ~ ``torch.nn``, ``delu.random`` ~ ``torch.random``, etc.)

#. ``delu.tools``: other handy tools for common scenarios
   (e.g. for implementing training loops)

Installation
------------

.. code-block:: none

    pip install delu

Usage
-----

*DeLU is a toolbox, not a framework,
so you can learn things and start using them in any order.*

The "API & Examples" section on the website is the main source of knowledge about DeLU:
it provides usage examples, explanation and docstrings.

How to contribute
-----------------

- Use `issues <https://github.com/Yura52/delu/issues>`_
  to report bugs, share ideas and give feedback.
- For pull requests, see
  `CONTRIBUTING.md <https://github.com/Yura52/delu/blob/main/CONTRIBUTING.md>`_.
